# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-12 15:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('places', '0003_country_and_attributes'),
    ]

    operations = [
        migrations.AddField(
            model_name='place',
            name='status',
            field=models.CharField(choices=[('draft', 'draft'), ('published', 'published'), ('deleted', 'deleted')], db_index=True, default='draft', max_length=20),
        ),
    ]
