# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-11 09:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('places', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='PlaceLink',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.URLField()),
                ('link_type', models.CharField(choices=[('website', 'Website'), ('facebook', 'Facebook'), ('twitter', 'Twitter'), ('instagram', 'Instagram')], default='website', max_length=20)),
            ],
        ),
        migrations.AlterModelOptions(
            name='place',
            options={'verbose_name': 'place', 'verbose_name_plural': 'places'},
        ),
        migrations.AddField(
            model_name='place',
            name='main_picture',
            field=models.ImageField(blank=True, null=True, upload_to='places/main_picture/'),
        ),
        migrations.AddField(
            model_name='placelink',
            name='place',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='places.Place'),
        ),
    ]
